From: tip-bot for Song Liu <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, songliubraving@fb.com,
hpa@zytor.com, jolsa@kernel.org, davidca@fb.com, acme@redhat.com,
tglx@linutronix.de, mingo@kernel.org
Subject: [tip:perf/core] perf utils: Silence "Couldn't synthesize bpf events" warning for EPERM
Date: Fri, 15 Feb 2019 01:32:21 -0800 [thread overview]
Message-ID: <tip-39f4a913d6d439178177cae8aa2e9a232160fd51@git.kernel.org> (raw)
In-Reply-To: <20190204193140.719740-1-songliubraving@fb.com>
Commit-ID: 39f4a913d6d439178177cae8aa2e9a232160fd51
Gitweb: https://git.kernel.org/tip/39f4a913d6d439178177cae8aa2e9a232160fd51
Author: Song Liu <songliubraving@fb.com>
AuthorDate: Mon, 4 Feb 2019 11:31:40 -0800
Committer: Arnaldo Carvalho de Melo <acme@redhat.com>
CommitDate: Thu, 14 Feb 2019 13:31:11 -0300
perf utils: Silence "Couldn't synthesize bpf events" warning for EPERM
Synthesizing BPF events is only supported for root. Silent warning msg
when non-root user runs perf-record.
Reported-by: David Carrillo-Cisneros <davidca@fb.com>
Signed-off-by: Song Liu <songliubraving@fb.com>
Tested-by: David Carrillo-Cisneros <davidca@fb.com>
Acked-by: Jiri Olsa <jolsa@kernel.org>
Cc: kernel-team@fb.com
Link: http://lkml.kernel.org/r/20190204193140.719740-1-songliubraving@fb.com
Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
---
tools/perf/util/bpf-event.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/tools/perf/util/bpf-event.c b/tools/perf/util/bpf-event.c
index 796ef793f4ce..62dda96b0096 100644
--- a/tools/perf/util/bpf-event.c
+++ b/tools/perf/util/bpf-event.c
@@ -236,8 +236,8 @@ int perf_event__synthesize_bpf_events(struct perf_tool *tool,
pr_debug("%s: can't get next program: %s%s",
__func__, strerror(errno),
errno == EINVAL ? " -- kernel too old?" : "");
- /* don't report error on old kernel */
- err = (errno == EINVAL) ? 0 : -1;
+ /* don't report error on old kernel or EPERM */
+ err = (errno == EINVAL || errno == EPERM) ? 0 : -1;
break;
}
fd = bpf_prog_get_fd_by_id(id);
prev parent reply other threads:[~2019-02-15 9:33 UTC|newest]
Thread overview: 4+ messages / expand[flat|nested] mbox.gz Atom feed top
2019-02-04 19:31 [PATCH] perf utils: silent " Song Liu
2019-02-04 19:33 ` Song Liu
2019-02-04 20:30 ` Jiri Olsa
2019-02-15 9:32 ` tip-bot for Song Liu [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-39f4a913d6d439178177cae8aa2e9a232160fd51@git.kernel.org \
--to=tipbot@zytor.com \
--cc=acme@redhat.com \
--cc=davidca@fb.com \
--cc=hpa@zytor.com \
--cc=jolsa@kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=songliubraving@fb.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome